pub trait ToBoxedFrameSlice<F>where
F: Frame,{
// Required method
fn to_boxed_frame_slice(self) -> Option<Box<[F]>>;
}Expand description
For converting from a boxed slice of Samples to a boxed slice of Frames.
pub trait ToBoxedFrameSlice<F>where
F: Frame,{
// Required method
fn to_boxed_frame_slice(self) -> Option<Box<[F]>>;
}For converting from a boxed slice of Samples to a boxed slice of Frames.