Detect

Trait Detect 

pub trait Detect<F>
where F: Frame,
{ type Output: Frame<NumChannels = F::NumChannels>; // Required method fn detect(&mut self, frame: F) -> Self::Output; }
Types that may be used to detect an envelope over a signal.

Required Associated Types

type Output: Frame<NumChannels = F::NumChannels>

The result of detection.

Required Methods

fn detect(&mut self, frame: F) -> Self::Output

Given some frame, return the detected envelope over each channel.

Implementors

Source

impl<F, R> Detect<F> for Peak<R>
where F: Frame, R: Rectifier<F>,

Source

type Output = <R as Rectifier<F>>::Output

Source

impl<F, S> Detect<F> for Rms<F, S>
where F: Frame, S: Slice<Element = F::Float> + SliceMut,

Source

type Output = <F as Frame>::Float