Struct sample::signal::Output [−][src]
pub struct Output<S> where
S: Signal, { /* fields omitted */ }An output node to which some signal S is Outputing its frames.
It may be more accurate to say that the Output "pull"s frames from the signal.
Methods
impl<S> Output<S> where
S: Signal, [src]
impl<S> Output<S> where
S: Signal, pub fn pending_frames(&self) -> usize[src]
pub fn pending_frames(&self) -> usizeThe number of frames that have been requested from the Signal S by some other Output
that have not yet been requested by this Output.
This is useful when using an Output to "monitor" some signal, allowing the user to drain
only frames that have already been requested by some other Output.
Example
extern crate sample; use sample::{signal, Signal}; fn main() { let frames = [[0.1], [0.2], [0.3]]; let bus = signal::from_iter(frames.iter().cloned()).bus(); let signal = bus.send(); let mut monitor = bus.send(); assert_eq!(signal.take(3).collect::<Vec<_>>(), vec![[0.1], [0.2], [0.3]]); assert_eq!(monitor.pending_frames(), 3); assert_eq!(monitor.next(), [0.1]); assert_eq!(monitor.pending_frames(), 2); }