Function zip_map_in_place

pub fn zip_map_in_place<FA, FB, M>(a: &mut [FA], b: &[FB], zip_map: M)
where FA: Frame, FB: Frame, M: FnMut(FA, FB) -> FA,
Mutate every frame in slice a while reading from each frame in slice b in lock-step using the given function.

Panics if the length of b is not equal to the length of a.