pub struct Rectangle;Expand description
The simplest window type, equivalent to replacing all but N values of data sequence by zeroes, making it appear as though the waveform suddenly turns on and off.