Struct sample::signal::Bus [−][src]
pub struct Bus<S> where
S: Signal, { /* fields omitted */ }A type which allows for sending a single Signal to multiple outputs.
This type manages
Methods
impl<S> Bus<S> where
S: Signal, [src]
impl<S> Bus<S> where
S: Signal, pub fn send(&self) -> Output<S>[src]
pub fn send(&self) -> Output<S>Produce a new Output node to which the signal S will output its frames.