Rate

Struct Rate 

pub struct Rate { /* private fields */ }
The rate at which phrase a Signal is sampled.

Implementations

Source

impl Rate

pub fn const_hz(self, hz: f64) -> ConstHz

Create a ConstHz signal which consistently yields hz / rate.

pub fn hz<S>(self, hz: S) -> Hz<S>
where S: Signal<Frame = [f64; 1]>,

Create a Hz signal which yields phase step sizes controlled by an input signal hz.

Example
extern crate sample;
 
use sample::{signal, Signal};
 
fn main() {
    let step = signal::rate(4.0).hz(signal::gen(|| [1.0]));
    let mut phase = signal::phase(step);
    assert_eq!(phase.next(), [0.0]);
    assert_eq!(phase.next(), [0.25]);
    assert_eq!(phase.next(), [0.5]);
    assert_eq!(phase.next(), [0.75]);
    assert_eq!(phase.next(), [0.0]);
    assert_eq!(phase.next(), [0.25]);
}