pub trait Step {
// Required method
fn step(&mut self) -> f64;
}Expand description
Types that may be used to give a phase step size based on some hz / sample rate.
This allows the Phase to be generic over either ConstHz and Hz<I>.
Generally, users need not be concerned with this trait unless writing code that must remain generic over phase stepping types like oscillators.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".