This module provides various helper functions for performing operations on slices of frames.
Functions
- add_
in_ place - Adds every sample in slice
bto every sample in slicearespectively. - add_
in_ place_ with_ amp_ per_ channel - Scale the amplitude of each frame in
bbyamp_per_channelbefore summing it ontoa. - equilibrium
- Sets the slice of frames at the associated
Sample’s equilibrium value. - from_
boxed_ frame_ slice - Converts the given boxed slice of
Frames into some sliceT. - from_
boxed_ sample_ slice - Converts the given boxed slice of
Samples into some sliceT. - from_
frame_ slice - Converts the given slice of
Frames into some sliceT. - from_
frame_ slice_ mut - Converts the given slice of mutable
Frames into some mutable sliceT. - from_
sample_ slice - Converts the given slice of
Samples into some sliceT. - from_
sample_ slice_ mut - Converts the given mutable slice of
Samples into some mutable sliceT. - map_
in_ place - Mutate every element in the slice with the given function.
- to_
boxed_ frame_ slice - Converts the given boxed slice into a boxed slice of
Frames. - to_
boxed_ sample_ slice - Converts the given boxed slice into a boxed slice of
Samples. - to_
frame_ slice - Converts the given slice into a slice of
Frames. - to_
frame_ slice_ mut - Converts the given mutable slice into a mutable slice of
Frames. - to_
sample_ slice - Converts the given slice into a slice of
Samples. - to_
sample_ slice_ mut - Converts the given mutable slice of
Frames into a mutable slice ofSamples. - write
- Writes every sample in slice
bto slicea. - zip_
map_ in_ place - Mutate every frame in slice
awhile reading from each frame in slicebin lock-step using the given function.