pub fn zip_map_in_place<FA, FB, M>(a: &mut [FA], b: &[FB], zip_map: M)Expand description
Mutate every frame in slice a while reading from each frame in slice b in lock-step using
the given function.
Panics if the length of b is not equal to the length of a.